==> 0.0.49.tar.gz: example/lib/Screen/SettingScreen.dart <==
import 'package:bui_component/DrawerComonent/kfDrawer.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:flutter/material.dart';
import 'package:bui_component/SettingScreenComponent.dart';
import 'package:shared_preferences/shared_preferences.dart';
import '../Utils/class_builder.dart';
import 'package:example/Constants/AppStrings.dart';
import 'package:bui_component/DataModalComponent/SlidableListView.dart';
import 'package:bui_component/CustomAlertComponent/CustomeAlert.dart';
import 'package:toast/toast.dart';

class SettingScreen extends KFDrawerContent {
  final Function() onMenuIconPressed;

  SettingScreen({this.onMenuIconPressed});

  @override
  _SettingScreenState createState() => _SettingScreenState();
}

class _SettingScreenState extends State<SettingScreen> {
  Color theme = AppColors.APP_COLOR_PRIMARY;

  @override
  void initState() {
    ClassBuilder.registerClasses();
    getStringValuesSF();

    data = List.generate(20, (index) {
      return index;
    });
    super.initState();
  }

  List<int> data = List();

  List<String> actions = ["Edit", "Delete"];

  getStringValuesSF() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    String stringValue = prefs.getString('stringValue');

    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);
      setState(() {
        theme = Color(colorCodeInt);
        this.mounted;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SettingScreenComponent(
          onMenuPressed: onMenuPressed,
          backgroundColor: theme,
          onMessageFunction: onMessageFunction,
          onNotificationFunction: onNotificationFunction,
          onSettingFunction: onSettingFunction,
          child: Stack(
            children: [
              // appBar,
              deleteDetailsView,
              detailsView
            ],
          )),
    );
  }

  Widget get deleteDetailsView {
    return Container(
      height: 30,
      margin: EdgeInsets.only(top: 60),
      width: MediaQuery.of(context).size.width,
      alignment: Alignment.center,
      child: Text(
        "Swipe left to use the edit and delete option",
        style: TextStyle(
            // fontWeight: FontWeight.bold,
            fontSize: 14,
            color: Colors.black87),
      ),
      color: Colors.grey[400],
      /*  decoration: BoxDecoration(
                color: Colors.grey[400],
                shape: BoxShape.rectangle,
                borderRadius: BorderRadius.only(
                    bottomLeft: Radius.circular(15.0),
                    bottomRight: Radius.circular(15.0))),*/
    );
  }

  Widget get appBar {
    return Container(
      height: 60,
      color: theme != null ? theme : AppColors.APP_COLOR_PRIMARY,
      child: Row(
        children: <Widget>[
          ClipRRect(
            borderRadius: BorderRadius.all(Radius.circular(32.0)),
            child: InkWell(
              splashColor: AppColors.errorWarning,
              focusColor: AppColors.APP_COLOR_WHITE,
              onTap: () {
                widget.onMenuPressed();
              },
              child: Padding(
                padding: const EdgeInsets.all(12.0),
                child: Icon(
                  Icons.menu,
                  color: Colors.white,
                ),
              ),
            ),
          ),
          SizedBox(
            width: 130,
          ),
          ClipRRect(
            borderRadius: BorderRadius.all(Radius.circular(32.0)),
            child: InkWell(
              splashColor: AppColors.errorWarning,
              focusColor: AppColors.APP_COLOR_WHITE,
              onTap: () {
                //widget.onMenuPressed();
              },
              child: Padding(
                padding: const EdgeInsets.all(12.0),
                child: Icon(
                  Icons.notifications_active,
                  color: Colors.white,
                ),
              ),
            ),
          ),
          SizedBox(
            width: 10,
          ),
          ClipRRect(
            borderRadius: BorderRadius.all(Radius.circular(32.0)),
            child: InkWell(
              splashColor: AppColors.errorWarning,
              focusColor: AppColors.APP_COLOR_WHITE,
              onTap: () {
                //widget.onMenuPressed();
              },
              child: Padding(
                padding: const EdgeInsets.all(12.0),
                child: Icon(
                  Icons.settings,
                  color: Colors.white,
                ),
              ),
            ),
          ),
          SizedBox(
            width: 10,
          ),
          ClipRRect(
            borderRadius: BorderRadius.all(Radius.circular(32.0)),
            child: InkWell(
              splashColor: AppColors.errorWarning,
              focusColor: AppColors.APP_COLOR_WHITE,
              onTap: () {
                //widget.onMenuPressed();
              },
              child: Padding(
                padding: const EdgeInsets.all(12.0),
                child: Icon(
                  Icons.messenger_rounded,
                  color: Colors.white,
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }

  Widget get detailsView {
    return Container(
      margin: EdgeInsets.only(top: 90),
      child: SlideListView(
        itemBackgroundColor: Colors.grey[200],
        itemBuilder: (bc, index) {
          return Container(
              width: MediaQuery.of(context).size.width,
              padding: EdgeInsets.all(5),
              //padding: EdgeInsets.all(10),
              child: Card(
                elevation: 0,
                shape: BeveledRectangleBorder(
                    borderRadius: BorderRadius.only(
                  bottomLeft: Radius.circular(15.0),
                  bottomRight: Radius.circular(15.0),
                  topLeft: Radius.circular(15.0),
                  topRight: Radius.circular(15.0),
                )),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Container(
                        width: MediaQuery.of(context).size.width,
                        decoration: BoxDecoration(
                            color: Colors.white,
                            shape: BoxShape.rectangle,
                            borderRadius: BorderRadius.only(
                                topLeft: Radius.circular(15.0),
                                topRight: Radius.circular(15.0))),
                        padding: EdgeInsets.all(10),
                        child: Text(
                          'Child ${data[index]}',
                          style: TextStyle(
                              fontWeight: FontWeight.bold,
                              fontSize: 16,
                              color: Colors.black87),
                        )),
                    Row(
                      crossAxisAlignment: CrossAxisAlignment.center,
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Container(
                            padding: EdgeInsets.all(10),
                            child: Text(
                              'Sub Child ${data[index]}',
                              style: TextStyle(
                                  fontWeight: FontWeight.w400,
                                  fontSize: 14,
                                  color: Colors.black87),
                            )),
                        Container(
                            padding: EdgeInsets.all(10),
                            child: Text(
                              'Content ${data[index]}',
                              style: TextStyle(
                                  fontWeight: FontWeight.w400,
                                  fontSize: 14,
                                  color: Colors.black87),
                            )),
                      ],
                    ),
                    /* Container(
                              padding: EdgeInsets.all(10),
                              child: Text(
                                'Sub Child ${data[index]}',
                                style: TextStyle(
                                    fontWeight: FontWeight.w400,
                                    fontSize: 14,
                                    color: Colors.black87),
                              )),
                          Container(
                              padding: EdgeInsets.all(10),
                              child: Text(
                                'Content ${data[index]}',
                                style: TextStyle(
                                    fontWeight: FontWeight.w300,
                                    fontSize: 12,
                                    color: Colors.black87),
                              )),*/
                    InkWell(
                      onTap: () {
                        Toast.show(data[index].toString(), context);
                      },
                      child: Container(
                          decoration: BoxDecoration(
                              color: Colors.white,
                              shape: BoxShape.rectangle,
                              borderRadius: BorderRadius.only(
                                  bottomLeft: Radius.circular(15.0),
                                  bottomRight: Radius.circular(15.0))),
                          alignment: Alignment.bottomRight,
                          padding: EdgeInsets.all(10),
                          child: Text(
                            AppStrings.VIEW_MORE,
                            style: TextStyle(
                                fontWeight: FontWeight.w900,
                                fontSize: 14,
                                color: Colors.black54),
                          )),
                    ),
                  ],
                ),
              ));
        },
        actionWidgetDelegate:
            ActionWidgetDelegate(actions.length, (actionIndex, listIndex) {
          if (actionIndex == 0) {
            return Column(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                Icon(
                  Icons.edit,
                  color: theme ?? AppColors.primaryColor,
                ),
                Text(
                  actions[0].toString(),
                  style: TextStyle(
                    fontWeight: FontWeight.bold,
                    fontSize: 14,
                    color: theme ?? AppColors.primaryColor,
                  ),
                ),
              ],
            );
          } else {
            return Column(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                Icon(Icons.delete, color: AppColors.errorWarning),
                Text(
                  actions[1].toString(),
                  style: TextStyle(
                      fontWeight: FontWeight.bold,
                      fontSize: 12,
                      color: AppColors.errorWarning),
                ),
              ],
            );
          }
          return Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[Container()],
          );
        }, (int indexInList, int index, BaseSlideItem item) {
          if (index == 0) {
            //item.remove();

            CustomAlertBox.showCustomAlertBox(
              context: context,
              type: "Warning",
              enterWidget: Text("Are you sure do you want to delete this Item"),
              isPositiveEnabled: true,
              isNegativeEnabled: true,
              setPositiveAction: () {
                item.remove();
                //Navigator.pop(context);
              },
            );
            //  _showMyDialog(indexInList, item);
          } else {
            item.close();
            CustomAlertBox.showCustomAlertBox(
              context: context,
              type: "Alert",
              enterWidget: Text("This is Sample Alert"),
              isPositiveEnabled: true,
              isNegativeEnabled: false,
              positiveButtonColor: Colors.green,
              setPositiveAction: () {
                // Navigator.pop(context);
              },
            );
            Toast.show("Close this Item", context);
          }
        }, [Colors.white, Colors.white]),
        dataList: data,
        refreshCallback: () async {
          await Future.delayed(Duration(seconds: 2));

          return;
        },
      ),
    );
  }

  Future<void> onMenuPressed() async {
    setState(() {
      widget.onMenuPressed();
      //widget.onMenuIconPressed();
    });
  }

  Future<void> onMessageFunction() async {
    setState(() {
      Toast.show("Message Pressed", context);
      //widget.onMenuIconPressed();
    });
  }

  Future<void> onSettingFunction() async {
    setState(() {
      Toast.show("Setting Pressed", context);
      //widget.onMenuIconPressed();
    });
  }

  Future<void> onNotificationFunction() async {
    setState(() {
      Toast.show("Notification Pressed", context);
      //widget.onMenuIconPressed();
    });
  }
}

==> 0.0.63.tar.gz: example/lib/Screen/SettingScreen.dart <==
import 'package:bui_component/DrawerComonent/kfDrawer.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:flutter/material.dart';
import 'package:bui_component/SettingScreenComponent.dart';
import 'package:shared_preferences/shared_preferences.dart';
import '../Utils/class_builder.dart';
import 'package:example/Constants/AppStrings.dart';
import 'package:bui_component/DataModalComponent/SlidableListView.dart';
import 'package:bui_component/CustomAlertComponent/CustomeAlert.dart';
import 'package:toast/toast.dart';

class SettingScreen extends KFDrawerContent {
  final Function() onMenuIconPressed;

  SettingScreen({this.onMenuIconPressed});

  @override
  _SettingScreenState createState() => _SettingScreenState();
}

class _SettingScreenState extends State<SettingScreen> {
  Color theme = AppColors.APP_COLOR_PRIMARY;

  @override
  void initState() {
    ClassBuilder.registerClasses();
    getStringValuesSF();

    data = List.generate(20, (index) {
      return index;
    });
    super.initState();
  }

  List<int> data = List();

  List<String> actions = ["Edit", "Delete"];

  getStringValuesSF() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);

    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);
      setState(() {
        theme = Color(colorCodeInt);
        this.mounted;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SettingScreenComponent(
          onMenuPressed: onMenuPressed,
          backgroundColor: theme,
          onMessageFunction: onMessageFunction,
          onNotificationFunction: onNotificationFunction,
          onSettingFunction: onSettingFunction,
          child: Stack(
            children: [
              // appBar,
              deleteDetailsView,
              detailsView
            ],
          )),
    );
  }

  Widget get deleteDetailsView {
    return Container(
      height: 30,
      margin: EdgeInsets.only(top: 60),
      width: MediaQuery.of(context).size.width,
      alignment: Alignment.center,
      child: Text(
        "Swipe left to use the edit and delete option",
        style: TextStyle(
            // fontWeight: FontWeight.bold,
            fontSize: 14,
            color: Colors.black87),
      ),
      color: Colors.grey[400],
      /*  decoration: BoxDecoration(
                color: Colors.grey[400],
                shape: BoxShape.rectangle,
                borderRadius: BorderRadius.only(
                    bottomLeft: Radius.circular(15.0),
                    bottomRight: Radius.circular(15.0))),*/
    );
  }

  Widget get appBar {
    return Container(
      height: 60,
      color: theme != null ? theme : AppColors.APP_COLOR_PRIMARY,
      child: Row(
        children: <Widget>[
          ClipRRect(
            borderRadius: BorderRadius.all(Radius.circular(32.0)),
            child: InkWell(
              splashColor: AppColors.errorWarning,
              focusColor: AppColors.APP_COLOR_WHITE,
              onTap: () {
                widget.onMenuPressed();
              },
              child: Padding(
                padding: const EdgeInsets.all(12.0),
                child: Icon(
                  Icons.menu,
                  color: Colors.white,
                ),
              ),
            ),
          ),
          SizedBox(
            width: 130,
          ),
          ClipRRect(
            borderRadius: BorderRadius.all(Radius.circular(32.0)),
            child: InkWell(
              splashColor: AppColors.errorWarning,
              focusColor: AppColors.APP_COLOR_WHITE,
              onTap: () {
                //widget.onMenuPressed();
              },
              child: Padding(
                padding: const EdgeInsets.all(12.0),
                child: Icon(
                  Icons.notifications_active,
                  color: Colors.white,
                ),
              ),
            ),
          ),
          SizedBox(
            width: 10,
          ),
          ClipRRect(
            borderRadius: BorderRadius.all(Radius.circular(32.0)),
            child: InkWell(
              splashColor: AppColors.errorWarning,
              focusColor: AppColors.APP_COLOR_WHITE,
              onTap: () {
                //widget.onMenuPressed();
              },
              child: Padding(
                padding: const EdgeInsets.all(12.0),
                child: Icon(
                  Icons.settings,
                  color: Colors.white,
                ),
              ),
            ),
          ),
          SizedBox(
            width: 10,
          ),
          ClipRRect(
            borderRadius: BorderRadius.all(Radius.circular(32.0)),
            child: InkWell(
              splashColor: AppColors.errorWarning,
              focusColor: AppColors.APP_COLOR_WHITE,
              onTap: () {
                //widget.onMenuPressed();
              },
              child: Padding(
                padding: const EdgeInsets.all(12.0),
                child: Icon(
                  Icons.messenger_rounded,
                  color: Colors.white,
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }

  Widget get detailsView {
    return Container(
      margin: EdgeInsets.only(top: 90),
      child: SlideListView(
        itemBackgroundColor: Colors.grey[200],
        itemBuilder: (bc, index) {
          return Container(
              width: MediaQuery.of(context).size.width,
              padding: EdgeInsets.all(5),
              //padding: EdgeInsets.all(10),
              child: Card(
                elevation: 0,
                shape: BeveledRectangleBorder(
                    borderRadius: BorderRadius.only(
                  bottomLeft: Radius.circular(15.0),
                  bottomRight: Radius.circular(15.0),
                  topLeft: Radius.circular(15.0),
                  topRight: Radius.circular(15.0),
                )),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Container(
                        width: MediaQuery.of(context).size.width,
                        decoration: BoxDecoration(
                            color: Colors.white,
                            shape: BoxShape.rectangle,
                            borderRadius: BorderRadius.only(
                                topLeft: Radius.circular(15.0),
                                topRight: Radius.circular(15.0))),
                        padding: EdgeInsets.all(10),
                        child: Text(
                          'Child ${data[index]}',
                          style: TextStyle(
                              fontWeight: FontWeight.bold,
                              fontSize: 16,
                              color: Colors.black87),
                        )),
                    Row(
                      crossAxisAlignment: CrossAxisAlignment.center,
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Container(
                            padding: EdgeInsets.all(10),
                            child: Text(
                              'Sub Child ${data[index]}',
                              style: TextStyle(
                                  fontWeight: FontWeight.w400,
                                  fontSize: 14,
                                  color: Colors.black87),
                            )),
                        Container(
                            padding: EdgeInsets.all(10),
                            child: Text(
                              'Content ${data[index]}',
                              style: TextStyle(
                                  fontWeight: FontWeight.w400,
                                  fontSize: 14,
                                  color: Colors.black87),
                            )),
                      ],
                    ),
                    /* Container(
                              padding: EdgeInsets.all(10),
                              child: Text(
                                'Sub Child ${data[index]}',
                                style: TextStyle(
                                    fontWeight: FontWeight.w400,
                                    fontSize: 14,
                                    color: Colors.black87),
                              )),
                          Container(
                              padding: EdgeInsets.all(10),
                              child: Text(
                                'Content ${data[index]}',
                                style: TextStyle(
                                    fontWeight: FontWeight.w300,
                                    fontSize: 12,
                                    color: Colors.black87),
                              )),*/
                    InkWell(
                      onTap: () {
                        Toast.show(data[index].toString(), context);
                      },
                      child: Container(
                          decoration: BoxDecoration(
                              color: Colors.white,
                              shape: BoxShape.rectangle,
                              borderRadius: BorderRadius.only(
                                  bottomLeft: Radius.circular(15.0),
                                  bottomRight: Radius.circular(15.0))),
                          alignment: Alignment.bottomRight,
                          padding: EdgeInsets.all(10),
                          child: Text(
                            AppStrings.VIEW_MORE,
                            style: TextStyle(
                                fontWeight: FontWeight.w900,
                                fontSize: 14,
                                color: Colors.black54),
                          )),
                    ),
                  ],
                ),
              ));
        },
        actionWidgetDelegate:
            ActionWidgetDelegate(actions.length, (actionIndex, listIndex) {
          if (actionIndex == 0) {
            return Column(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                Icon(
                  Icons.edit,
                  color: theme ?? AppColors.primaryColor,
                ),
                Text(
                  actions[0].toString(),
                  style: TextStyle(
                    fontWeight: FontWeight.bold,
                    fontSize: 14,
                    color: theme ?? AppColors.primaryColor,
                  ),
                ),
              ],
            );
          } else {
            return Column(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                Icon(Icons.delete, color: AppColors.errorWarning),
                Text(
                  actions[1].toString(),
                  style: TextStyle(
                      fontWeight: FontWeight.bold,
                      fontSize: 12,
                      color: AppColors.errorWarning),
                ),
              ],
            );
          }
          return Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[Container()],
          );
        }, (int indexInList, int index, BaseSlideItem item) {
          if (index == 0) {
            //item.remove();

            CustomAlertBox.showCustomAlertBox(
              context: context,
              type: "Warning",
              enterWidget: Text("Are you sure do you want to delete this Item"),
              isPositiveEnabled: true,
              isNegativeEnabled: true,
              setPositiveAction: () {
                item.remove();
                //Navigator.pop(context);
              },
            );
            //  _showMyDialog(indexInList, item);
          } else {
            item.close();
            CustomAlertBox.showCustomAlertBox(
              context: context,
              type: "Alert",
              enterWidget: Text("This is Sample Alert"),
              isPositiveEnabled: true,
              isNegativeEnabled: false,
              positiveButtonColor: Colors.green,
              setPositiveAction: () {
                // Navigator.pop(context);
              },
            );
            Toast.show("Close this Item", context);
          }
        }, [Colors.white, Colors.white]),
        dataList: data,
        refreshCallback: () async {
          await Future.delayed(Duration(seconds: 2));

          return;
        },
      ),
    );
  }

  Future<void> onMenuPressed() async {
    setState(() {
      widget.onMenuPressed();
      //widget.onMenuIconPressed();
    });
  }

  Future<void> onMessageFunction() async {
    setState(() {
      Toast.show("Message Pressed", context);
      //widget.onMenuIconPressed();
    });
  }

  Future<void> onSettingFunction() async {
    setState(() {
      Toast.show("Setting Pressed", context);
      //widget.onMenuIconPressed();
    });
  }

  Future<void> onNotificationFunction() async {
    setState(() {
      Toast.show("Notification Pressed", context);
      //widget.onMenuIconPressed();
    });
  }
}
